@@ -1,7 +1,8 @@
-use log::{debug, error, info, warn, LevelFilter};
-
+use log::*;
 pub fn main() {
+    #[cfg(feature = "logging")]
     wolf_engine::initialize_logging(LevelFilter::Debug);
+
     info!("Hello, world!");
     debug!("This is some debug information.");
     warn!("Here is a warning!");
